==> af-common-jpa-1.1.16.51-sources.jar: com/af/v4/system/common/jpa/transformer/StandardAliasTransformer.java <==
package com.af.v4.system.common.jpa.transformer;

import cn.hutool.core.date.DateUtil;
import com.af.v4.system.common.jpa.utils.ClobUtil;
import org.hibernate.transform.AliasedTupleSubsetResultTransformer;
import org.json.JSONObject;

import java.math.BigDecimal;
import java.sql.Clob;
import java.util.Date;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * 标准结果转换器
 */
public class StandardAliasTransformer extends AliasedTupleSubsetResultTransformer {

    public static final StandardAliasTransformer INSTANCE = new StandardAliasTransformer();

    /**
     * Disallow instantiation of AliasToEntityMapResultTransformer.
     */
    private StandardAliasTransformer() {
    }

    protected static void runTrans(Object obj, Object[] tuple, String[] aliases) {
        for (int i = 0; i < aliases.length; i++) {
            String alias = aliases[i];
            Object value = tuple[i];
            switch (value) {
                case null -> value = JSONObject.NULL;
                case BigDecimal bigDecimal -> {
                    if (isIntegerValue(bigDecimal)) {
                        long longValue = bigDecimal.longValue();
                        if (longValue < Integer.MAX_VALUE) {
                            value = (int) longValue;
                        } else {
                            value = longValue;
                        }
                    }
                }
                case Date date ->
                    // 处理日期格式
                        value = DateUtil.formatDateTime(date);
                case Clob clob -> value = ClobUtil.getClobString(clob);
                default -> {
                }
            }
            if (obj instanceof JSONObject object) {
                object.put(alias.toLowerCase(), value);
            } else if (obj instanceof Map objectMap) {
                objectMap.put(alias.toLowerCase(), value);
            }
        }
    }

    private static boolean isIntegerValue(BigDecimal bd) {
        return bd.stripTrailingZeros().scale() <= 0;
    }

    @Override
    public Map<String, Object> transformTuple(Object[] tuple, String[] aliases) {
        Map<String, Object> objectMap = new LinkedHashMap<>(aliases.length);
        runTrans(objectMap, tuple, aliases);
        return objectMap;
    }

    @Override
    public boolean isTransformedValueATupleElement(String[] aliases, int tupleLength) {
        return false;
    }
}

==> af-common-jpa-1.1.18.15-sources.jar: com/af/v4/system/common/jpa/transformer/StandardAliasTransformer.java <==
package com.af.v4.system.common.jpa.transformer;

import cn.hutool.core.date.DateUtil;
import com.af.v4.system.common.jpa.utils.ClobUtil;
import org.hibernate.transform.AliasedTupleSubsetResultTransformer;
import org.json.JSONObject;
import org.json.JSONParserConfiguration;

import java.math.BigDecimal;
import java.sql.Clob;
import java.util.Date;
import java.util.Map;

/**
 * 标准结果转换器
 */
public class StandardAliasTransformer extends AliasedTupleSubsetResultTransformer {

    public static final StandardAliasTransformer INSTANCE = new StandardAliasTransformer();

    /**
     * Disallow instantiation of AliasToEntityMapResultTransformer.
     */
    private StandardAliasTransformer() {
    }

    protected static void runTrans(Object obj, Object[] tuple, String[] aliases) {
        for (int i = 0; i < aliases.length; i++) {
            String alias = aliases[i];
            Object value = tuple[i];
            switch (value) {
                case null -> value = JSONObject.NULL;
                case BigDecimal bigDecimal -> {
                    if (isIntegerValue(bigDecimal)) {
                        long longValue = bigDecimal.longValue();
                        if (longValue < Integer.MAX_VALUE) {
                            value = (int) longValue;
                        } else {
                            value = longValue;
                        }
                    }
                }
                case Date date ->
                    // 处理日期格式
                        value = DateUtil.formatDateTime(date);
                case Clob clob -> value = ClobUtil.getClobString(clob);
                default -> {
                }
            }
            if (obj instanceof JSONObject object) {
                object.put(alias.toLowerCase(), value);
            } else if (obj instanceof Map objectMap) {
                objectMap.put(alias.toLowerCase(), value);
            }
        }
    }

    private static boolean isIntegerValue(BigDecimal bd) {
        return bd.stripTrailingZeros().scale() <= 0;
    }

    @Override
    public JSONObject transformTuple(Object[] tuple, String[] aliases) {
        JSONObject result = new JSONObject(new JSONParserConfiguration().setOrdered(true));
        runTrans(result, tuple, aliases);
        return result;
    }

    @Override
    public boolean isTransformedValueATupleElement(String[] aliases, int tupleLength) {
        return false;
    }
}
